import { Component } from '@angular/core';
import { delay, of, shareReplay, Subject, switchMap } from 'rxjs';

@Component({
  selector: 'app-root',
  templateUrl: './app.component.html',
  styleUrls: ['./app.component.css'],
})
export class AppComponent {
  public config = {
    features: {
      tree: true,
      stripe: true,
      sort: false,
      taskEdit: false,
      scheduleTooltip: false,
      scheduleMenu: false,
      cellMenu: false,
      eventDragCreate: false,
      eventTooltip: {
        disabled: true,
      },
      eventMenu: true,
      eventResize: false,
      eventDrag: false,
      timeRanges: {
        showCurrentTimeLine: true,
      },
    },
    columns: [
      {
        width: 200,
        type: 'tree',
        field: 'name',
        editor: false,
      },
    ],
    viewPreset: {
      timeResolution: {
        unit: 'minute',
        increment: 15,
      },
      headers: [
        {
          unit: 'day',
          dateFormat: 'DD MMMM',
        },
        {
          unit: 'minute',
          increment: 60,
          dateFormat: 'HH:mm',
        },
      ],
    },
  };

  public startDate = '2023-01-05T10:00:00.000Z';
  public endDate = '2023-01-05T23:00:00.000Z';

  public loadDataSubject = new Subject<void>();
  public data$ = this.loadDataSubject.pipe(
    switchMap(() => {
      return of(this._generateData()).pipe(delay(5000));
    }),
    shareReplay(1)
  );

  private _generateData() {
    const resources = [];
    const events = [];
    for (let i = 0; i < 10000; i++) {
      const resourceId = `North:${i}`;

      resources.push({
        id: resourceId,
        name: `Testing name - ${i}`,
      });

      events.push({
        id: i,
        manuallyScheduled: true,
        resourceId,
        startDate: '2023-01-05T18:00:00.000Z',
        endDate: '2023-01-05T21:00:00.000Z',
      });
    }
    return {
      events,
      resources,
    };
  }

  public loadDataFromServer() {
    this.loadDataSubject.next();
  }
}
